======
aiosip
======

.. image:: https://badge.fury.io/py/aiosip.png
    :target: http://badge.fury.io/py/aiosip


SIP support for AsyncIO written in pure Python.

**Warning: SIP knowledge is necessary to use this library.**

See **examples/** folder for examples.

* Free software: Apache2 license

Features tested on production
-----------------------------

* SIP endpoint client mode
* UDP support
* REGISTER
* NOTIFY
* SUBSCRIBE
* MESSAGE

Missing features
----------------

* Documentation
* unit tests
* TCP support
* SIP proxy/server mode
* SDP support
